aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/libpng/png.pas8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/libpng/png.pas b/src/lib/libpng/png.pas
index 0092dde3..b5ea49e8 100644
--- a/src/lib/libpng/png.pas
+++ b/src/lib/libpng/png.pas
@@ -30,10 +30,10 @@ uses
const
{$IFDEF MSWINDOWS}
- // use libpng12-0 (Version 1.2.18), delivered wih SDL_Image
- LibPng = 'libpng12-0'; // 'libpng13';
- // matching lib version for libpng13.dll, needed for initialization
- PNG_LIBPNG_VER_STRING='1.2.12';
+ // use libpng15-15 (Version 1.2.15), delivered wih SDL_Image
+ LibPng = 'libpng15-15';
+ // matching lib version for libpngxx.dll, needed for initialization
+ PNG_LIBPNG_VER_STRING='1.2.15';
// define the compiler that was used to built the DLL (necessary for jmp_buf)
// SDL_Image was compiled with GCC
//{$define MSVC_DLL} // MS Visual C++